![Coverage badge](https://raw.githubusercontent.com/TUW-GEO/eotransform/python-coverage-comment-action-data/badge.svg)
# eotransform

Defines the basic transform protocol to be used in the streamed source to sink concept. Also provides some generic 
transformer implementations such as `Compose` or `Map`.

WIP: More Doc